==> GeneSpring_1.0.1.tar.gz: GeneSpring/man/GSload.exp.Rd <==
\name{GSload.exp}
\alias{GSload.exp}
\alias{GSload.expBC}
%- Also NEED an '\alias' for EACH other topic documented here.

\title{ Read GeneSpring Experiment from file}

\description{
A GeneSpring Experiment is read in, usually from a file,
but a connection object (like \code{stdin()}) can also be passed.
The return value can either be an object of class \code{GSint} or
BioConductor \code{exprSet} representing the Experiment Interpretation
from GeneSpring.
}

\usage{
gs.int<-GSload.exp(filename = "GS_R_in.txt")
expr.set<-GSload.expBC(filename = "GS_R_in.txt")
}

%- maybe also 'usage' for other objects documented here.

\arguments{
\item{filename}{ Name of the file containing the GeneSpring Experiment Interpretation. Can also be a connection object.}
}

\details{
A GeneSpring Experiment is quite distinct from a GeneSpring Experiment INTERPRETATION.
See \code{\link{GSload.int}} for more information on GeneSpring Experiment Interpretations.

A GeneSpring Experiment consists of the Normalized expression values for each sample
and optionally the Control values for that normalized value. The control values for an
experiment are the values that are used to create the normalized values by simply
dividing the Raw expression value by the Control value. The GeneSpring Normalization
routines will calculate the control values for each gene and these values can be used
in subsequent analysis.

In a GeneSpring Experiment, each sample or hybridization has its own column (set)
of expression values, wheras the expression values for an Experiment INTERPRETATION
represent the mean value of the replicate values for that condition.

For example, if there are 4 replicates for samples of time 0, there will be
one column of normalized data for time 0 in the Experiment Interpretation,
and there will be four columns of average values for each of the replicates, in
the GeneSpring Experiment.

The experimental parameters for the experiment, are stored in the header of the file,
with each sample's parameter in columns above the expression values. When control values
are present in the file, the paramter value is simply \code{control}.

The names of the experimental parameters can also indicate whether or not the parameter
has any unit indentifier (like hour, mM, etc.) and this will be a suffix of the 
parameter name in parenthesis. The experimental parameters will also contain an
indication wheter or not the values are numeric or not, but the addition of an
asterisk character for non-numeric values and the absence of the asterisk for numerical values.

The final character of the parameter name will indicate how the parameter was used
in GeneSpring. When the parameter is used as a discontinuous parameter, the character
is a \sQuote{C}. When the parareter is used as a color coding paramter, the character
is a \sQuote{S}. When the parameter is not used to indicate a group or color coding
the character is a \sQuote{R}. When a parameter was used as the continuous parameter,
the last character is missing or empty.

When loading experimental parameters from file, the units and indication of use will be discarded.


}

}

\value{
The return value depends on which fucntion was called.
The \code{GSload.exp} function returns a object of class \code{GSint}.
The \code{GSload.expBC} function returns a BioConductor object of class \code{exprSet}.
See the documentation on \code{GSint} and \code{exprSet} for more information.
}
\references{ 

For more information on using GeneSpring with R see
\url{http://www.silicongenetics.com/cgi/SiG.cgi/Support/GeneSpring/GSnotes/R.smf}
}

\author{ 
   Thon de Boer, Silicon Genetics, Redwood city, CA, USA \email{thon@silicongenetics.com}

}

\note{ This and any other functions in the GeneSpring package are only useful,
when using Silicon Genetics Gene Expression software GeneSpring.
}

\seealso{
\code{\link{GSload.int}},
\code{\link{GSsave.exp}},
\code{\link{GSint2BC}},
\code{\link{BC2GSint}}
}
\examples{

}
\keyword{ IO }% at least one, from doc/KEYWORDS

==> GeneSpring_2.4.0.tar.gz: GeneSpring/man/GSload.exp.Rd <==
\name{GSload.exp}
\alias{GSload.exp}
\alias{GSload.expBC}
%- Also NEED an '\alias' for EACH other topic documented here.

\title{ Read GeneSpring Experiment from file}

\description{
A GeneSpring Experiment is read in, usually from a file,
but a connection object (like \code{stdin()}) can also be passed.
The return value can either be an object of class \code{GSint} or
BioConductor \code{exprSet} representing the Experiment Interpretation
from GeneSpring.
}

\usage{
gs.int<-GSload.exp(filename = "GS_R_in.txt")
expr.set<-GSload.expBC(filename = "GS_R_in.txt")
}

%- maybe also 'usage' for other objects documented here.

\arguments{
\item{filename}{ Name of the file containing the GeneSpring Experiment Interpretation. Can also be a connection object.}
}

\details{
A GeneSpring Experiment is quite distinct from a GeneSpring Experiment INTERPRETATION.
See \code{\link{GSload.int}} for more information on GeneSpring Experiment Interpretations.

A GeneSpring Experiment consists of the Normalized expression values for each sample
and optionally the Control values for that normalized value. The control values for an
experiment are the values that are used to create the normalized values by simply
dividing the Raw expression value by the Control value. The GeneSpring Normalization
routines will calculate the control values for each gene and these values can be used
in subsequent analysis.

In a GeneSpring Experiment, each sample or hybridization has its own column (set)
of expression values, wheras the expression values for an Experiment INTERPRETATION
represent the mean value of the replicate values for that condition.

For example, if there are 4 replicates for samples of time 0, there will be
one column of normalized data for time 0 in the Experiment Interpretation,
and there will be four columns of average values for each of the replicates, in
the GeneSpring Experiment.

The experimental parameters for the experiment, are stored in the header of the file,
with each sample's parameter in columns above the expression values. When control values
are present in the file, the paramter value is simply \code{control}.

The names of the experimental parameters can also indicate whether or not the parameter
has any unit indentifier (like hour, mM, etc.) and this will be a suffix of the 
parameter name in parenthesis. The experimental parameters will also contain an
indication wheter or not the values are numeric or not, but the addition of an
asterisk character for non-numeric values and the absence of the asterisk for numerical values.

The final character of the parameter name will indicate how the parameter was used
in GeneSpring. When the parameter is used as a discontinuous parameter, the character
is a \sQuote{C}. When the parareter is used as a color coding paramter, the character
is a \sQuote{S}. When the parameter is not used to indicate a group or color coding
the character is a \sQuote{R}. When a parameter was used as the continuous parameter,
the last character is missing or empty.

When loading experimental parameters from file, the units and indication of use will be discarded.


}

}

\value{
The return value depends on which fucntion was called.
The \code{GSload.exp} function returns a object of class \code{GSint}.
The \code{GSload.expBC} function returns a BioConductor object of class \code{exprSet}.
See the documentation on \code{GSint} and \code{exprSet} for more information.
}
\references{ 

For more information on using GeneSpring with R see
\url{http://www.chem.agilent.com/scripts/generic.asp?lpage=34733}
}

\author{ 
   Thon de Boer, Agilent Technologies, Santa Clara, CA, USA \email{thon\_deboer@agilent.com}
}

\note{ This and any other functions in the GeneSpring package are only useful,
when using Agilent Technologies Gene Expression software GeneSpring.
}

\seealso{
\code{\link{GSload.int}},
\code{\link{GSsave.exp}},
\code{\link{GSint2BC}},
\code{\link{BC2GSint}}
}
\examples{

}
\keyword{ IO }% at least one, from doc/KEYWORDS
